Primitives
==========

Classes
-------

.. currentmodule:: ansys.edb.core.primitive

.. autosummary::
   :toctree: _autosummary

   board_bend_def.BoardBendDef
   bondwire.Bondwire
   circle.Circle
   padstack_instance.PadstackInstance
   path.Path
   primitive.Primitive
   polygon.Polygon
   rectangle.Rectangle
   text.Text
   primitive_instance_collection.PrimitiveInstanceCollection

Enums
-----
.. currentmodule:: ansys.edb.core

.. autosummary::
   :toctree: _autosummary

   primitive.bondwire.BondwireCrossSectionType
   primitive.bondwire.BondwireType
   primitive.padstack_instance.BackDrillType
   primitive.path.PathCornerType
   primitive.path.PathEndCapType
   primitive.primitive.PrimitiveType
   primitive.rectangle.RectangleRepresentationType
   edb_defs.LayoutObjType